==> resource-manager-1.0.3.tgz: package/src/lazy.ts <==
import Vue, { Component as VueComponent, VNode } from 'vue';
import { error } from '@vue-async/utils';
import { PropsDefinition, DefaultProps } from 'vue/types/options';
import { del, add, has } from './Suspense';
import { currentSuspenseInstance } from './currentInstance';
import findSuspenseInstance from './findSuspenseInstance';
import { AsyncFactory, SuspenseComponent } from '../types';

export default function Lazy<PropsDef = PropsDefinition<DefaultProps>>(
  asyncFactory: AsyncFactory,
  props?: PropsDef,
): VueComponent {
  return Vue.extend({
    name: 'SuspenseLazy',
    props: props,
    created() {
      asyncFactory.suspenseInstance = (currentSuspenseInstance as Vue) || findSuspenseInstance(this);

      if (has(asyncFactory)) return;

      add(asyncFactory);

      if (asyncFactory.resolved) {
        (asyncFactory.$$waiter as Promise<SuspenseComponent>).then(() => {
          del(asyncFactory);
        });
        return;
      }
      const promise = asyncFactory();
      asyncFactory.$$waiter = promise;

      promise
        .then((C) => {
          // Compatible ES Module
          if (C.__esModule && C.default) {
            C = C.default;
          }
          asyncFactory.resolved = C;
          // Trigger update
          this.$forceUpdate();
        })
        .catch((err) => {
          error(process.env.NODE_ENV === 'production', err);
          del(asyncFactory, err);
        });
    },
    updated() {
      del(asyncFactory);
    },
    render(this: Vue, h) {
      // Fix context
      const slots = Object.keys(this.$slots)
        .reduce((arr, key) => (arr as VNode[]).concat(this.$slots[key] || []), [] as VNode[])
        .map((vnode: VNode) => {
          vnode.context = this._self;
          return vnode;
        });

      return asyncFactory.resolved
        ? h(
            asyncFactory.resolved as VueComponent,
            {
              on: this.$listeners,
              // If there is no props definition, fall back to `this.$attrs`
              props: props ? this.$props : this.$attrs,
              // Passthrough scopedSlots
              scopedSlots: this.$scopedSlots,
              attrs: this.$attrs,
            },
            slots,
          )
        : this._e();
    },
  });
}

==> resource-manager-1.0.7.tgz: package/src/lazy.ts <==
import Vue, { Component as VueComponent, VNode } from 'vue';
import { error } from '@vue-async/utils';
import { PropsDefinition, DefaultProps } from 'vue/types/options';
import { del, add, has } from './Suspense';
import { currentSuspenseInstance } from './currentInstance';
import findSuspenseInstance from './findSuspenseInstance';

// Types
import { AsyncFactory, SuspenseComponent } from 'types/resource-mananger';

export default function Lazy<PropsDef = PropsDefinition<DefaultProps>>(
  asyncFactory: AsyncFactory,
  props?: PropsDef,
): VueComponent {
  return Vue.extend({
    name: 'SuspenseLazy',
    props: props,
    created() {
      asyncFactory.suspenseInstance = (currentSuspenseInstance as Vue) || findSuspenseInstance(this);

      if (has(asyncFactory)) return;

      add(asyncFactory);

      if (asyncFactory.resolved) {
        (asyncFactory.$$waiter as Promise<SuspenseComponent>).then(() => {
          del(asyncFactory);
        });
        return;
      }
      const promise = asyncFactory();
      asyncFactory.$$waiter = promise;

      promise
        .then((C) => {
          // Compatible ES Module
          if (C.__esModule && C.default) {
            C = C.default;
          }
          asyncFactory.resolved = C;
          // Trigger update
          this.$forceUpdate();
        })
        .catch((err) => {
          error(process.env.NODE_ENV === 'production', err);
          del(asyncFactory, err);
        });
    },
    updated() {
      del(asyncFactory);
    },
    render(this: Vue, h) {
      // Fix context
      const slots = Object.keys(this.$slots)
        .reduce((arr, key) => (arr as VNode[]).concat(this.$slots[key] || []), [] as VNode[])
        .map((vnode: VNode) => {
          vnode.context = this._self;
          return vnode;
        });

      return asyncFactory.resolved
        ? h(
            asyncFactory.resolved as VueComponent,
            {
              on: this.$listeners,
              // If there is no props definition, fall back to `this.$attrs`
              props: props ? this.$props : this.$attrs,
              // Passthrough scopedSlots
              scopedSlots: this.$scopedSlots,
              attrs: this.$attrs,
            },
            slots,
          )
        : this._e();
    },
  });
}
